from keras.models import load_model
from keras.preprocessing import image
import numpy as np
import os
import cv2
import pkg_resources

def get_model_path():
  return pkg_resources.resource_filename(__name__, "model.h5")


import gdown
file_id = '12MeKZg6KY_aQH2Dd4c25y2HpiEQqJTiY'
output_file = 'model.h5'
url = f'https://drive.google.com/uc?id={file_id}'
gdown.download(url, output_file, quiet=False)





img_size = (145, 145)

def preprocess_image(filepath):
    img_array = cv2.imread(filepath, cv2.IMREAD_COLOR)
    img_array = img_array / 255
    resized_array = cv2.resize(img_array, (145, 145))
    return resized_array.reshape(-1, 145, 145, 3)

def Face_Mash(img_path,model_path):
     model = load_model(model_path)
     img_array = preprocess_image(img_path)
     predictions = model.predict(img_array)
     prediction_class = np.argmax(predictions, axis=1)
     class_labels = ["yawn", "no_yawn", "Closed", "Open"]
     predicted_class_label = class_labels[prediction_class[0]]
     return predicted_class_label




from setuptools import setup
import setuptools

from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()
setup(
    name='Face_Mash',
    version='127.0.0.0',
    description='Deep Learning model for fatigue detection',
    author='Murali,Monica',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    keywords=['deep learning', 'drowsiness detection', 'fatigue analysis'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    py_modules=['Face_Mash'],
    package_data={'Face_Mash': ['model.h5']},
    install_requires=[
        'keras>=2.6.0',
        'opencv-python>=4.5.3',
        'numpy>=1.19.5',
        'tensorflow>=2.13.0',
        'gdown>=4.7.1'
    ]
)
